summaryrefslogtreecommitdiffstats
path: root/kpilot/listCat.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:03:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:03:51 -0600
commit0fec53a48e99adff6836591ad47842b00202446f (patch)
tree58843637df571723c859a4e47e3b8125ced58347 /kpilot/listCat.h
parentc657df4df56ade1e7e3de5112b0ee4034dca9874 (diff)
downloadkpilot-0fec53a48e99adff6836591ad47842b00202446f.tar.gz
kpilot-0fec53a48e99adff6836591ad47842b00202446f.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kpilot/listCat.h')
-rw-r--r--kpilot/listCat.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpilot/listCat.h b/kpilot/listCat.h
index 32c808a..d844692 100644
--- a/kpilot/listCat.h
+++ b/kpilot/listCat.h
@@ -8,7 +8,7 @@
*/
/** @file
** This is a specialization of KListView to allow the user to
** DnD a fixed set of objects into a fixed set of categories
** (categories set at construction time). @em Deprecated, do not use.
*/
@@ -38,13 +38,13 @@
class TQStringList;
/**
* This Widget extends KListView for a particular purpose:
* sorting some items into some bins. This can be useful
* for putting items in an enabled / disabled state, or
* into categories, or configuring toolbars (putting
* icons onto toolbars).
*
* You can use all of the standard KListView signals and
* slots. You may in particular want to change the names
* of the columns, for example:
* @code
@@ -61,7 +61,7 @@ class TQStringList;
* @version $Id$
*/
-class ListCategorizer : public KListView
+class ListCategorizer : public TDEListView
{
Q_OBJECT
@@ -189,7 +189,7 @@ protected:
private:
/**
* Call several KListView functions to set up useful
* behavior for this particular class.
*/
void setupWidget();
@@ -8,7 +8,7 @@
*/
/** @file
-** This is a specialization of KListView to allow the user to
+** This is a specialization of TDEListView to allow the user to
** DnD a fixed set of objects into a fixed set of categories
** (categories set at construction time). @em Deprecated, do not use.
@@ -38,13 +38,13 @@
class TQStringList;
/**
- * This Widget extends KListView for a particular purpose:
+ * This Widget extends TDEListView for a particular purpose:
* sorting some items into some bins. This can be useful
* for putting items in an enabled / disabled state, or
@@ -38,13 +38,13 @@
* icons onto toolbars).
*
- * You can use all of the standard KListView signals and
+ * You can use all of the standard TDEListView signals and
* slots. You may in particular want to change the names
* of the columns, for example:
@@ -189,7 +189,7 @@ protected:
private:
/**
- * Call several KListView functions to set up useful
+ * Call several TDEListView functions to set up useful
* behavior for this particular class.
*/